@@ -370,10 +370,10 @@ void Textblock::recognize( const Charset & charset, const Filter & filter ) thro
   for( int i = textlines() - 1; i >= 0; --i )
     {
     Textline & line1 = *tlpv[i];
-    bool flag = false;
+    bool recognized = false;
     for( int j = 0 ; j < line1.characters(); ++j )
-      { if( line1.character( j ).guesses() ) { flag = true; break; } }
-    if( !flag ) delete_line( tlpv, i );
+      { if( line1.character( j ).guesses() ) { recognized = true; break; } }
+    if( !recognized ) delete_line( tlpv, i );
     }
 
   // Add blank lines.
