@@ -64,7 +64,7 @@ int blobs_in_page( const std::vector< Zone > & zone_vector ) throw()
   }
 
 
-void bprint( const std::vector< Zone > & zone_vector, FILE * outfile ) throw()
+void bprint( const std::vector< Zone > & zone_vector, FILE * const outfile ) throw()
   {
 //  std::fprintf( outfile, "page size %dw x %dh\n", width(), height() );
   std::fprintf( outfile, "total zones in page %d\n", (int)zone_vector.size() );
@@ -437,7 +437,7 @@ void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector
 } // end namespace
 
 
-Textpage::Textpage( const Page_image & page_image, const char * filename,
+Textpage::Textpage( const Page_image & page_image, const char * const filename,
                     const Control & control, const bool layout )
   : Rectangle( page_image ), name( filename )
   {
